==> haskell-dav-1.3.4-856-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-D1Cu6iYDehR2HOQrLzATZq
key:                  DAV-1.3.4-D1Cu6iYDehR2HOQrLzATZq
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  6ee7a8f58ad336e38f728237e8d29994
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-D1Cu6iYDehR2HOQrLzATZq
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-DLRBsz9VfqUNwIWg4HsHR containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd exceptions-0.10.5
    http-client-0.7.19-Je5Ncol09LTKkFF5WfHhv1
    http-client-tls-0.3.6.4-EFTVUXlq4cM19RusFvekJW
    http-types-0.12.4-6ojMayzAfwB91OTgOklzJ2
    lens-5.3.3-26VlyqkFVMA2DXZQVmsUyD mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-9a385SIdm505uSRtbGh5Pa
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    utf8-string-1.0.2-4OrQf1vZkgOAJqnDO7nv41
    xml-conduit-1.9.1.4-HeToZQfn8xl4La8Cfm2IjS
    xml-hamlet-0.5.0.2-J5GIYtKQtJEDmsy0ltwSNe

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.4-857-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-Hw4n58E6B4b3QpbE2zuEPi
key:                  DAV-1.3.4-Hw4n58E6B4b3QpbE2zuEPi
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  5857d4cbf23d60ca2006fda8d6f47f0b
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-Hw4n58E6B4b3QpbE2zuEPi
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-DLRBsz9VfqUNwIWg4HsHR containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd exceptions-0.10.5
    http-client-0.7.19-Je5Ncol09LTKkFF5WfHhv1
    http-client-tls-0.3.6.4-EFTVUXlq4cM19RusFvekJW
    http-types-0.12.4-6ojMayzAfwB91OTgOklzJ2
    lens-5.3.3-26VlyqkFVMA2DXZQVmsUyD mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-9a385SIdm505uSRtbGh5Pa
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    utf8-string-1.0.2-4OrQf1vZkgOAJqnDO7nv41
    xml-conduit-1.9.1.4-HeToZQfn8xl4La8Cfm2IjS
    xml-hamlet-0.5.0.2-BWe4U40RbkcBKPKAgSkloJ

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
